@@ -4,6 +4,6 @@ function(object, ...)
   if(class(object)=="gets" || class(object)=="isat"){
     return(object$terminals)
   }else{
-    cat("The object does not belong to the 'gets' nor 'isat' class\n")
+    cat("object not of class 'gets' or 'isat' class\n")
   }
 }
